document.addEventListener('DOMContentLoaded', () => {
  const playButton = document.querySelector('.btn-play');
  const progressBar = document.querySelector('.progress');
  const volumeSlider = document.querySelector('.volume-slider');
  const channels = document.querySelectorAll('.channel');
  const visualizationSphere = document.querySelector('.visualization-sphere');
  
  let isPlaying = false;
  let currentProgress = 0;
  
  playButton.addEventListener('click', () => {
    isPlaying = !isPlaying;
    playButton.querySelector('.icon').textContent = isPlaying ? '⏸' : '▶';
    
    if (isPlaying) {
      startVisualization();
    } else {
      stopVisualization();
    }
  });

  volumeSlider.addEventListener('input', (e) => {
    const value = e.target.value;
    updateVisualization(value);
  });

  function startVisualization() {
    visualizationSphere.style.animation = 'pulse 4s infinite ease-in-out';
    simulateChannelActivity();
  }

  function stopVisualization() {
    visualizationSphere.style.animation = 'none';
    channels.forEach(channel => channel.classList.remove('active'));
  }

  function updateVisualization(intensity) {
    const opacity = intensity / 100;
    visualizationSphere.style.opacity = opacity;
  }

  function simulateChannelActivity() {
    if (!isPlaying) return;

    channels.forEach(channel => {
      if (Math.random() > 0.5) {
        channel.classList.add('active');
      } else {
        channel.classList.remove('active');
      }
    });

    setTimeout(simulateChannelActivity, 500);
  }

  // Simulate progress bar movement
  function updateProgress() {
    if (isPlaying) {
      currentProgress = (currentProgress + 0.1) % 100;
      progressBar.style.width = `${currentProgress}%`;
    }
    requestAnimationFrame(updateProgress);
  }

  updateProgress();
});